mathtools.BoundedObject
=======================

.. abjad-lineage:: abjad.tools.mathtools.BoundedObject.BoundedObject

.. autoclass:: abjad.tools.mathtools.BoundedObject.BoundedObject

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.mathtools.BoundedObject.BoundedObject.is_closed
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.is_half_closed
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.is_half_open
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.is_left_closed
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.is_left_open
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.is_open
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.is_right_closed
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.is_right_open
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.__eq__
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.__format__
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.__hash__
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.__ne__
      ~abjad.tools.mathtools.BoundedObject.BoundedObject.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.is_closed
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.is_half_closed
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.is_half_open
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.is_open
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.is_left_closed
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.is_left_open
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.is_right_closed
   :noindex:

.. autoattribute:: abjad.tools.mathtools.BoundedObject.BoundedObject.is_right_open
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.__format__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.__hash__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.BoundedObject.BoundedObject.__repr__
   :noindex:
